import { Component, ViewChild } from '@angular/core';
import { FormArray, FormBuilder, FormGroup, NgForm, Validators } from '@angular/forms';
import { ActivatedRoute, Router } from '@angular/router';
import { BlockUI, NgBlockUI } from 'ng-block-ui';
import { BuildingService } from '../../service/monitoring-api.service';
import { LoginService } from '../../service/login.service';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-add-edit-list',
  templateUrl: './add-edit-list.component.html',
  styleUrls: ['./add-edit-list.component.css']
})
export class AddEditListComponent {
  // @ViewChild("f", { read: true }) userProfileForm: NgForm;

  model: any = {};
  mode: string;
  public breadcrumb: any;
  projectInfo: FormGroup;
  submitted = false;

  dataBuildingList: any;
  dataRoomList: any;
  dataMasterStatus: any;
  roombuildingId: any;
  dataRoomBuilding: any;
  disableButton: boolean = true;
  // userProfileForm: FormGroup;
  public userList: FormArray;

  @BlockUI("projectInfo") blockUIProjectInfo: NgBlockUI;
  get userFormGroup() {
    return this.projectInfo.get('userArray') as FormArray;
  }

  constructor(
    private formBuilder: FormBuilder,
    private router: Router,
    private route: ActivatedRoute,
    private monitoringApiService: BuildingService,
    private authService: LoginService,
    private toastr: ToastrService,
  ) {}

  ngOnInit() {
    this.authService.startTokenCheck();
    this.authService.startTrackingActivity();
    this.route.data.subscribe((data) => {
      this.mode = data.mode;
    });
    this.route.params.subscribe(params => {
      const id = params['id'];
      this.roombuildingId = id;
      if (id) {
        this.loadRoomBuilding(id);
      }
    });
    this.setBreadcrumb();
    this.dataListBuilding();
    this.dataListRoom();
    this.dataListMaster();

    this.projectInfo = this.formBuilder.group({
      buildingId: ["", Validators.required],
      roomId: [""],
      statusId: ["", Validators.required],
      userArray: this.formBuilder.array([this.createRoom()]),
    });
    this.userList = this.projectInfo.get('userArray') as FormArray;
  }

  createRoom(): FormGroup {
    return this.formBuilder.group({
      roomId: ['', Validators.required]
    });
  }

  addPhone() {
    this.userList.push(this.createRoom());
    this.disableButton = true
  }

  removePhone(index) {
    this.userList.removeAt(index);
    this.isRoomDuplicate(index)
  }

  validateDouble(event: any, index: number) {
    const selectedRoomId = (event.target as HTMLSelectElement).value;
    if (this.isRoomDuplicate(index)) {
      this.disableButton = true
      this.toastr.error("Room", "Data yang ada masukan double!", {
        timeOut: 2000,
        closeButton: true,
      });
    } else {
      this.disableButton = false
    }
  }

  isRoomDuplicate(index: number): boolean {
    const selectedRooms = this.userFormGroup.value.map((room) => room.roomId);
    const currentRoomId = selectedRooms[index];
    const roomOccurrences = selectedRooms.filter(roomId => roomId === currentRoomId).length;
    if (roomOccurrences === 0) {
      this.disableButton = false
    }
    return roomOccurrences > 1;
  }

  setBreadcrumb() {
    if (this.isAddMode()) {
      this.breadcrumb = {
        mainlabel: "List Monitoring",
        links: [
          {
            name: "Home",
            isLink: false,
          },
          {
            name: "List Monitoring",
            isLink: false,
          },
          {
            name: "Add New List Monitoring",
            isLink: false,
          },
        ],
      };
    } else if (this.isEditMode()) {
      this.breadcrumb = {
        mainlabel: "List Monitoring",
        links: [
          {
            name: "Home",
            isLink: false,
          },
          {
            name: "List Monitoring",
            isLink: false,
          },
          {
            name: "Edit New List Monitoring",
            isLink: false,
          },
        ],
      };
    }
  }

  loadRoomBuilding(deviceId: string) {
    this.monitoringApiService.getRoomBuildingById(deviceId).subscribe(data => {
      this.dataRoomBuilding = data;
      this.formGetDevice(data)
    });
  }

  formGetDevice(data){
    this.projectInfo.patchValue({
      buildingId: data.data.buildingId,
      roomId: data.data.roomId,
      statusId: data.data.statusId,
    });
    
    if (this.mode === 'view') {
      this.formDisable();
    }
  }

  formDisable(){
    this.projectInfo.get('buildingId').disable()
    this.projectInfo.get('roomId').disable()
    this.projectInfo.get('statusId').disable()
  }

  isEditMode() {
    return this.mode === "edit";
  }

  isViewMode() {
    return this.mode === "view";
  }

  isAddMode() {
    return this.mode === "add";
  }

  get f() {
    return this.projectInfo.controls;
  }

  onProjectInfoSubmit() {
    this.submitted = true;
    if (this.projectInfo.invalid) {
      return;
    }
  }

  keyPress(event: any) {
    const pattern = /[0-9\+\-\ ]/;
    const inputChar = String.fromCharCode(event.charCode);
    if (event.keyCode !== 8 && !pattern.test(inputChar)) {
      event.preventDefault();
    }
  }

  dataListBuilding() {
    this.monitoringApiService.getBuildingList().subscribe(data => {
      this.dataBuildingList = data.data.filter(item => item.statusName.toLowerCase() === "aktif" || item.status_id === 71)
    });
  }

  dataListRoom() {
    this.monitoringApiService.getListRoomDataUnmap().subscribe(data => {
      const newArray = data.data.map(item => ({
        id: item.id,
        name: `${item.name} (${item.code})`
      }));
      this.dataRoomList = newArray
    });
  }

  dataListMaster() {
    this.monitoringApiService.getMasterListData().subscribe(data => {
      const dataStatus = data.data.find(
        (item) => item.name === "master_status"
      ).headerDetailParam;
      this.dataMasterStatus = dataStatus.filter(item => item.statusName.toLowerCase() === "aktif" || item.status.toLowerCase() === "71")
    });
  }

  save() {
    if (this.mode === 'add') {
      if (this.projectInfo.invalid) {
        return;
      }
      const formData = this.projectInfo.value;
      const transformedData = {
        buildingId: formData.buildingId,
        roomId: formData.userArray.map(room => room.roomId),
        statusId: formData.statusId
      };
      this.monitoringApiService.postBatchBuilding(transformedData).subscribe((res) => {
        this.router.navigate(["/list-monitoring"]);
      });
    } else {
      delete this.projectInfo.value.userArray;
      this.monitoringApiService.puttBuildingRoom(this.projectInfo.value, this.roombuildingId).subscribe(data => {
        this.router.navigate(["/list-monitoring"]);
      });
    }
  }

  cancel() {
    this.router.navigate(["/list-monitoring"]);
  }
}
